@@ -5,7 +5,7 @@ NULL
 #'
 #' Use these expectations to test other expectations.
 #' Use `show_failure()` in examples to print the failure message without
-#' throwing an erorr.
+#' throwing an error.
 #'
 #' @param expr Expression that evaluates a single expectation.
 #' @param message Check that the failure message matches this regexp.
@@ -56,7 +56,7 @@ show_failure <- function(expr) {
   exp <- capture_expectation(expr)
 
   if (!is.null(exp) && expectation_failure(exp)) {
-    cat(crayon::bold("Failued expectation:\n"))
+    cat(crayon::bold("Failed expectation:\n"))
     cat(exp$message, "\n", sep = "")
   }
 
